@@ -124,6 +124,9 @@ iris %>% describe(Species)
 # describe a categorical variable
 iris %>% describe(Sepal.Length)
 
+## ----message=FALSE, warning=FALSE, fig.width=6, fig.height=3------------------
+use_data_beer() %>% describe()
+
 ## ----message=FALSE, warning=FALSE, fig.width=6, fig.height=3------------------
 # create dataset and describe it
 data <- create_data_app(obs = 100)
@@ -149,19 +152,6 @@ describe(data)
 ## ----message=FALSE, warning=FALSE, fig.width=6, fig.height=3------------------
 data %>% select(random_starsign, random_moon) %>% explore_all()
 
-## ----eval=FALSE, echo=TRUE----------------------------------------------------
-#  iris  %>%  data_dict_md(output_dir = tempdir())
-
-## ----eval=FALSE, echo=TRUE----------------------------------------------------
-#  description <- data.frame(
-#                    variable = c("Species"),
-#                    description = c("Species of Iris flower"))
-#  data_dict_md(iris,
-#               title = "iris flower data set",
-#               description =  description,
-#               output_file = "data_dict_iris.md",
-#               output_dir = tempdir())
-
 ## ----message=FALSE, warning=FALSE, fig.width=6, fig.height=3------------------
 iris %>% 
   clean_var(Sepal.Length, 
@@ -171,6 +161,15 @@ iris %>%
             name = "sepal_length") %>% 
   describe()
 
+## ----message=FALSE, warning=FALSE, fig.width=6, fig.height=3------------------
+use_data_penguins() %>% 
+  describe_tbl()
+
+## ----message=FALSE, warning=FALSE, fig.width=6, fig.height=3------------------
+use_data_penguins() %>%
+  drop_obs_with_na() %>%
+  describe_tbl()
+
 ## ----eval=FALSE, message=FALSE, warning=FALSE---------------------------------
 #  create_notebook_explore(
 #    output_dir = tempdir(),
