@@ -267,3 +267,35 @@ test_that("create_data_unfair()", {
     TRUE
   )
 })
+
+
+# create_data_esoteric ----------------------------------------------------
+
+# create dataset with obs
+test_that("create_data_esoteric()", {
+  expect_equal(
+    nrow(create_data_esoteric(obs = 100)),
+    100
+  )
+})
+
+# error if obs < 1
+test_that("create_data_esoteric()", {
+  expect_error(create_data_esoteric(obs = -1))
+})
+
+# create dataset is reproducible when using the same seed
+test_that("create_data_esoteric()", {
+  expect_equal(
+    create_data_esoteric(obs = 100, seed = 1),
+    create_data_esoteric(obs = 100, seed = 1)
+  )
+})
+
+# add_id works
+test_that("create_data_esoteric()", {
+  expect_true(
+    ncol(create_data_esoteric(obs = 100, add_id = TRUE)) ==
+    ncol(create_data_esoteric(obs = 100, add_id = FALSE)) + 1
+  )
+})
